from cmk.gui.i18n import _
from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersApplications
)

from cmk.gui.valuespec import (
    Dictionary,
    ListChoice,
    Tuple,
    Percentage,
    Integer,
    Float,
)

def _parameter_spec_nextcloud_info():
    return Dictionary(
        elements=[
            ("levels_apps_with_updates_available", Tuple(
                title=_("Nextcloud number of installed apps with updates available"),
                    elements=[
                        Integer(
                            title=_("Warning at"),
                            default_value=1,
                        ),
                        Integer(
                            title=_("Critical at"),
                            default_value=2,
                        )
                    ],
            )),
            ("levels_free_space", Tuple(
                title=_("Nextcloud levels for free disk space overall"),
                    elements=[
                        Float(
                            title=_("Warning below"),
                            default_value=8.0,
                            unit="GBytes",
                        ),
                        Float(
                            title=_("Critical below"),
                            default_value=4.0,
                            unit="GBytes",
                        )
                    ],
            )),
            ("levels_number_of_files", Tuple(
                title=_("Nextcloud number of files"),
                    elements=[
                        Integer(
                            title=_("Warning at"),
                            default_value=100000,
                        ),
                        Integer(
                            title=_("Critical at"),
                            default_value=250000,
                        )
                    ],
            )),
        ],
    )

rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="nextcloud_info",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_spec_nextcloud_info,
        title=lambda: _("Nextcloud Info"),
    )
)